@@ -94,7 +94,7 @@ human_Imperial_ODE <- function(t, state, parameters) {
         clin_inc <- phi * FOI * Y
         fv <- 1 - (1-fvS)/(1+(age_days/av)^gammaV)
         immunity_multiplier <- ((IVA+IVM)/iv0)^kv
-        severe_disease <- theta0*(theta1 + ((1-theta1)/(1+fv*immunity_multiplier)))*infected
+        severe_disease <- theta0*(theta1 + ((1-theta1)/(1+fv*immunity_multiplier)))*FOI
         mort <- pctMort*severe_disease
 
         for (i in 1:(na)) {
