@@ -608,10 +608,16 @@ make_pupae_2unmated_haz <- function(trans,u,m_ix,cube,params,exact = TRUE,tol =
 # MALE TRANSITIONS
 ################################################################################
 
-make_male_mort_haz <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8){
+make_male_mort_haz <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8, trap_idx = NULL){
 
   # rate constants
+
+  # if we're in a trap node, set mortality to 0
+  node_num <- trans$node
   muM <- params$muM
+  if(!is.null(node_num) && node_num %in% trap_idx) {
+    muM <- 0
+  }
 
   # which places have input arcs to this transition
   s <- trans$s
@@ -661,10 +667,14 @@ make_male_mort_haz <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8){
 # FEMALE TRANSITIONS
 ################################################################################
 
-make_female_mort_haz <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8){
+make_female_mort_haz <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8, trap_idx = NULL){
 
+  node_num <- trans$node
   # rate constants
   muF <- params$muF
+  if(!is.null(node_num) && node_num %in% trap_idx) {
+    muF <- 0
+  }
 
   # which places have input arcs to this transition
   s <- trans$s
