@@ -12,18 +12,21 @@
 #' adult interventions - indoor residual spraying (IRS) and insecticide treated nets (ITN)
 #' This is based on the work of Le Menach et al (2007) and Griffin et al (2010).
 #' We vary three parameters in the presence of interventions:
-#' Egg laying rate (beta),
-#' Adult mortality (muF),
-#' Mosquito biting rate (av0)
+#'  Egg laying rate (beta)
+#'  Adult mortality (muF)
+#'  Mosquito biting rate (av0)
+#'
 #' @name add_interventions
+#'
 #' @param params a named list of parameters
-#' @param IRS_cov proportion of humans in the node receiving IRS 
-#' @param LLIN_cov proportion of humans in the node receiving LLIN 
+#' @param IRS_cov proportion of humans in the node receiving IRS
+#' @param LLIN_cov proportion of humans in the node receiving LLIN
 #'
 #' @return a vector of the equilibrium number of females in each SEI stage
+#'
 #' @export
 add_interventions <- function(params, IRS_cov, LLIN_cov) {
-  if (LLIN_cov == 0 & IRS_cov == 0) {
+  if((LLIN_cov == 0) && (IRS_cov == 0)){
     return(params)
   }
   # TODO check that LLIN_cov and ITS_cov are proportions
